library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;
use IEEE.math_real.all;

library work;
use work.settings.all;

-- Controler of analog to digital converter
--  * on calibration request: perform Vcompare calibration 
--  * on sampling request: increase (decrease) Vcompare if it is smaller (greater) then Vscaled
--  * estimate Vcompare by the sequence of charge and discharge cycles
--  * calculate moving average of Vcompare
--  * confirm end of sampling, if Vcompare crosses its moving average
-- 
-- author: 
-- date:   
entity ADC_CONTROL is
  port (
    CLK       : in  std_logic;                                 -- clock
    RSTN      : in  std_logic;                                 -- synchronous reset (active low) 
    COMPARE   : in  std_logic;                                 -- Vcompare > Vscaled?
    CALIBRATE : in  std_logic;                                 -- synchronous calibration request (active high)
    SAMPLE    : in  std_logic;                                 -- synchronous sampling request (active high)
    DONE      : out std_logic;                                 -- synchronous sampling confirmation (active high)
    SCALED    : out std_logic_vector(SAMPLE_WIDTH-1 downto 0); -- sampled value of Vscaled
    CHARGE    : out std_logic);                                -- Vcompare manipulation signal
end entity;
------------------------------------------------------------------------------------------------------------------------