library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;
use IEEE.math_real.all;

library work;
use work.settings.all;

-- Minimum application utilizing the ADC
--  * generate sampling requests at fixed sampling rate
--  * translate user input into gain and calibration requests
--  * forward sampled value to UART transmitter
-- 
-- author: 
-- date:   
entity APPLICATION is
  port (
    CLK       : in  std_logic;                                 -- clock
    RSTN      : in  std_logic;                                 -- synchronous reset (active low)
    SWITCH    : in  std_logic_vector(             4 downto 0); -- asynchronous user input
    GAIN      : out std_logic_vector(             3 downto 0); -- asynchronous PGA gain request
    UNSCALED  : in  std_logic_vector(SAMPLE_WIDTH+3 downto 0); -- sampled value normalized by current PGA gain
    CALIBRATE : out std_logic;                                 -- synchronous calibration request (active high)
    SAMPLE    : out std_logic;                                 -- synchronous sampling request (active high)
    DONE      : in  std_logic;                                 -- synchronous sampling confirmation (active high) 
    D         : out std_logic_vector(             7 downto 0); -- byte to be transmitted via UART
    WEN       : out std_logic;                                 -- synchronous UART write enable (active low)
    RDY       : in  std_logic);                                -- synchronous UART ready confirmation (active high)
end entity;
------------------------------------------------------------------------------------------------------------------------