library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;

-- Clock conditioning and reset synchronization
--  * reduce 48 MHz to 4 MHz by static PLL
--  * reduce 4 MHz to 4 MHz / (DIV+1) by a clock divider
--  * generate synchronous resets for both output clocks
-- 
-- author: 
-- date:   
entity CLOCK_CONDITIONING is
  port (
    OSC_CLK   : in  std_logic;                    -- 48 MHz oscillator clock                    
    PO_RSTN   : in  std_logic;                    -- asynchronous power on reset (active low)   
    PB_RSTN   : in  std_logic;                    -- asynchronous push-button reset (active low)
    DIV       : in  std_logic_vector(3 downto 0); -- clock divider-1                            
    LOCK      : out std_logic;                    -- asynchronous PLL lock (active high)        
    CLK       : out std_logic;                    -- 4 MHz clock                                
    RSTN      : out std_logic;                    -- synchronous reset (active low) for clk     
    DCLK      : out std_logic;                    -- 4 MHz / (DIV+1) clock                      
    DRSTN     : out std_logic);                   -- synchronous reset (active low) for dclk    
end entity;
------------------------------------------------------------------------------------------------------------------------