library IEEE;
use IEEE.std_logic_1164.all;

library igloo;
use igloo.all;

library work;
use work.settings.all;

-- Comparator selection.
-- Set OPAMP_TYPE = 1 to instantiate an LVPECL input buffer
--                 -1 to instantiate an LVDS input buffer
--                  0 to instantiate the combinatorial logic for comparator simulation
-- 
-- author: Andreas Engel
-- date:   03/13
entity OPAMP is
  port (
    VP : in  std_logic;       -- positive comparator input
    VN : in  std_logic;       -- negative comparator input
    O  : out std_logic);      -- comparator output
end entity;
------------------------------------------------------------------------------------------------------------------------

architecture arch of OPAMP is

  component INBUF_LVPECL is 
    port(
      PADP : in  std_logic;
      PADN : in  std_logic; 
      Y    : out std_logic);
  end component;
  
  component INBUF_LVDS is 
    port(
      PADP : in  std_logic;
      PADN : in  std_logic; 
      Y    : out std_logic);
  end component;
  
begin
  
  g_lvpecl: if OPAMP_TYPE > 0 generate
    i_opamp : INBUF_LVPECL port map (VP, VN, O);
  end generate;
  
  g_lvds: if OPAMP_TYPE < 0 generate
    i_opamp : INBUF_LVDS   port map (VP, VN, O);
  end generate;
  
  g_simulation: if OPAMP_TYPE = 0 generate
    O <= VP and not VN;
  end generate;
  
end architecture;
