library ieee;
use ieee.std_logic_1164.all;

-- UART transmitter
--  * forward transmission interface of general UART core
--  * baudrate = CLK / (2*baudvalue+16)
-- 
-- author: Andreas Engel
-- date:   03/13
entity UTX is
  port(
    CLK        : in  std_logic;                       -- clock
    RSTN       : in  std_logic;                       -- synchronous reset (active low)
    BAUD_VALUE : in  std_logic_vector(15 downto 0);   -- communication speed configuration
    D          : in  std_logic_vector( 7 downto 0);   -- byte to transmit
    WEN        : in  std_logic;                       -- synchronous UART write enable (active low) 
    RDY        : out std_logic;                       -- synchronous UART ready confirmation (active high) 
    TX         : out std_logic);                      -- UART output data
end entity;
------------------------------------------------------------------------------------------------------------------------


architecture arch of UTX is

  --Actel:DirectCore:COREUART:5.1.102
  component COREUART is
    generic( 
      BAUD_VAL_FRCTN_EN : integer :=  1;
      FAMILY            : integer := 20;
      RX_FIFO           : integer :=  0;
      RX_LEGACY_MODE    : integer :=  0;
      TX_FIFO           : integer :=  0);
    port(
      BAUD_VAL          : in  std_logic_vector(12 downto 0);
      BAUD_VAL_FRACTION : in  std_logic_vector( 2 downto 0);
      BIT8              : in  std_logic;
      CLK               : in  std_logic;
      CSN               : in  std_logic;
      DATA_IN           : in  std_logic_vector( 7 downto 0);
      ODD_N_EVEN        : in  std_logic;
      OEN               : in  std_logic;
      PARITY_EN         : in  std_logic;
      RESET_N           : in  std_logic;
      RX                : in  std_logic;
      WEN               : in  std_logic;
      DATA_OUT          : out std_logic_vector( 7 downto 0);
      FRAMING_ERR       : out std_logic;
      OVERFLOW          : out std_logic;
      PARITY_ERR        : out std_logic;
      RXRDY             : out std_logic;
      TX                : out std_logic;
      TXRDY             : out std_logic);
  end component;

begin

  i_uart : COREUART
    port map( 
      CLK               => CLK,
      RESET_N           => RSTN,
      DATA_IN           => D,
      WEN               => WEN,
      TXRDY             => RDY,
      TX                => TX,
      BAUD_VAL          => BAUD_VALUE(15 downto 3),
      BAUD_VAL_FRACTION => BAUD_VALUE( 2 downto 0),
      
      CSN               => '0',
      ODD_N_EVEN        => '0',
      OEN               => '1',
      PARITY_EN         => '0',
      RX                => '1',
      BIT8              => '1',
      RXRDY             => open,
      PARITY_ERR        => open,
      OVERFLOW          => open,
      FRAMING_ERR       => open,
      DATA_OUT          => open);

end architecture;
